@@ -24,7 +24,7 @@ import java.util.Scanner;
 public class BandwidthFileImpl extends DescriptorImpl implements BandwidthFile {
 
   private enum KeyWithStringValue {
-    version, software, software_version
+    version, software, software_version, tor_version
   }
 
   private enum KeyWithLocalDateTimeValue {
@@ -66,6 +66,7 @@ public class BandwidthFileImpl extends DescriptorImpl implements BandwidthFile {
         this.parseRelayLine(line);
       }
     }
+    this.calculateDigestSha256Base64();
   }
 
   private void parseTimestampLine(String line) throws DescriptorParseException {
@@ -94,6 +95,7 @@ public class BandwidthFileImpl extends DescriptorImpl implements BandwidthFile {
       case "version":
       case "software":
       case "software_version":
+      case "tor_version":
         this.parsedStrings.put(KeyWithStringValue.valueOf(key), value);
         break;
       case "file_created":
@@ -257,6 +259,11 @@ public class BandwidthFileImpl extends DescriptorImpl implements BandwidthFile {
         additionalKeyValues.isEmpty() ? null : additionalKeyValues));
   }
 
+  @Override
+  public String digestSha256Base64() {
+    return this.getDigestSha256Base64();
+  }
+
   private LocalDateTime timestamp;
 
   @Override
@@ -285,6 +292,12 @@ public class BandwidthFileImpl extends DescriptorImpl implements BandwidthFile {
         this.parsedStrings.get(KeyWithStringValue.software_version));
   }
 
+  @Override
+  public Optional<String> torVersion() {
+    return Optional.ofNullable(
+        this.parsedStrings.get(KeyWithStringValue.tor_version));
+  }
+
   private EnumMap<KeyWithLocalDateTimeValue, LocalDateTime> parsedLocalDateTimes
       = new EnumMap<>(KeyWithLocalDateTimeValue.class);
 
@@ -428,4 +441,3 @@ public class BandwidthFileImpl extends DescriptorImpl implements BandwidthFile {
         : Collections.unmodifiableList(this.relayLines);
   }
 }
-
