@@ -1,4 +1,4 @@
-/* Copyright 2011--2018 The Tor Project
+/* Copyright 2011--2020 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.descriptor.impl;
@@ -223,26 +223,6 @@ public class ParseHelper {
         ZoneOffset.UTC);
   }
 
-  protected static long parseDateAtIndex(String line, String[] parts,
-      int dateIndex) throws DescriptorParseException {
-    if (dateIndex >= parts.length) {
-      throw new DescriptorParseException("Line '" + line + "' does not "
-          + "contain a date at the expected position.");
-    }
-    long result = -1L;
-    try {
-      DateFormat dateFormat = getDateFormat("yyyy-MM-dd");
-      result = dateFormat.parse(parts[dateIndex]).getTime();
-    } catch (ParseException e) {
-      /* Leave result at -1L. */
-    }
-    if (result < 0L || result / 1000L > (long) Integer.MAX_VALUE) {
-      throw new DescriptorParseException("Illegal date format in line '"
-          + line + "'.");
-    }
-    return result;
-  }
-
   protected static String parseTwentyByteHexString(String line,
       String hexString) throws DescriptorParseException {
     return parseHexString(line, hexString, 40);
@@ -330,18 +310,11 @@ public class ParseHelper {
 
   protected static void verifyThirtyTwoByteBase64String(String line,
       String base64String) throws DescriptorParseException {
-    convertThirtyTwoByteBase64StringToHex(line, base64String);
-  }
-
-  private static String convertThirtyTwoByteBase64StringToHex(String line,
-      String base64String) throws DescriptorParseException {
     if (!thirtyTwoByteBase64Pattern.matcher(base64String).matches()) {
       throw new DescriptorParseException("'" + base64String
           + "' in line '" + line + "' is not a valid base64-encoded "
           + "32-byte value.");
     }
-    return Hex.encodeHexString(Base64.decodeBase64(base64String + "="))
-        .toUpperCase();
   }
 
   protected static String parseCommaSeparatedKeyIntegerValueList(
@@ -564,5 +537,27 @@ public class ParseHelper {
     }
     return parsedProtocolVersions.get(lineNoOpt);
   }
-}
 
+  private static Map<String, SortedMap<String, Double>>
+      parsedStats = new HashMap<>();
+
+  protected static SortedMap<String, Double> parseStats(
+      String line, String lineNoOpt, String[] partsNoOpt)
+      throws DescriptorParseException {
+    if (!parsedStats.containsKey(lineNoOpt)) {
+      SortedMap<String, Double> parsed = new TreeMap<>();
+      try {
+        for (int i = 1; i < partsNoOpt.length; i++) {
+          String[] part = partsNoOpt[i].split("=");
+          Double stats = Double.parseDouble(part[1]);
+          parsed.put(part[0], stats);
+        }
+
+      } catch (ArrayIndexOutOfBoundsException | NumberFormatException e) {
+        throw new DescriptorParseException("Invalid line '" + line + "'.", e);
+      }
+      parsedStats.put(lineNoOpt, Collections.unmodifiableSortedMap(parsed));
+    }
+    return parsedStats.get(lineNoOpt);
+  }
+}
