@@ -28,8 +28,8 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
       Key.IDENTITY_ED25519, Key.MASTER_KEY_ED25519, Key.PLATFORM, Key.PROTO,
       Key.FINGERPRINT, Key.HIBERNATING, Key.UPTIME, Key.CONTACT, Key.FAMILY,
       Key.READ_HISTORY, Key.WRITE_HISTORY, Key.EVENTDNS, Key.CACHES_EXTRA_INFO,
-      Key.EXTRA_INFO_DIGEST, Key.HIDDEN_SERVICE_DIR, Key.PROTOCOLS,
-      Key.ALLOW_SINGLE_HOP_EXITS, Key.ONION_KEY, Key.SIGNING_KEY,
+      Key.EXTRA_INFO_DIGEST, Key.HIDDEN_SERVICE_DIR, Key.OVERLOAD_GENERAL,
+      Key.PROTOCOLS, Key.ALLOW_SINGLE_HOP_EXITS, Key.ONION_KEY, Key.SIGNING_KEY,
       Key.IPV6_POLICY, Key.NTOR_ONION_KEY, Key.ONION_KEY_CROSSCERT,
       Key.NTOR_ONION_KEY_CROSSCERT, Key.TUNNELLED_DIR_SERVER,
       Key.ROUTER_SIG_ED25519, Key.ROUTER_SIGNATURE, Key.ROUTER_DIGEST_SHA256,
@@ -76,6 +76,9 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
         case BANDWIDTH:
           this.parseBandwidthLine(line, partsNoOpt);
           break;
+        case OVERLOAD_GENERAL:
+          this.parseOverloadGeneralLine(line, partsNoOpt);
+          break;
         case PLATFORM:
           this.parsePlatformLine(lineNoOpt);
           break;
@@ -294,6 +297,24 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
     }
   }
 
+  private void parseOverloadGeneralLine(String line,
+      String[] partsNoOpt) throws DescriptorParseException {
+    int overloadGeneralVersion = Integer.parseInt(partsNoOpt[1]);
+    if (overloadGeneralVersion != 1) {
+      throw new DescriptorParseException("Unknown version number for line '"
+              + line + "' in extra-info descriptor.");
+    } else {
+      this.overloadGeneralVersion = overloadGeneralVersion;
+    }
+    if (partsNoOpt.length < 4) {
+      throw new DescriptorParseException("Missing fields for line '"
+              + line + "' in extra-info descriptor.");
+    }
+    this.overloadGeneralTimestamp = ParseHelper.parseTimestampAtIndex(line,
+            partsNoOpt, 2, 3);
+
+  }
+
   private void parsePlatformLine(String lineNoOpt) {
     if (lineNoOpt.length() > Key.PLATFORM.keyword.length() + 1) {
       this.platform = lineNoOpt.substring(Key.PLATFORM.keyword.length() + 1);
@@ -726,6 +747,20 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
     return this.bandwidthObserved;
   }
 
+  private int overloadGeneralVersion = 0;
+
+  @Override
+  public int getOverloadGeneralVersion() {
+    return this.overloadGeneralVersion;
+  }
+
+  private long overloadGeneralTimestamp = -1L;
+
+  @Override
+  public long getOverloadGeneralTimestamp() {
+    return this.overloadGeneralTimestamp;
+  }
+
   private String platform;
 
   @Override
