@@ -1917,5 +1917,30 @@ public class RelayNetworkStatusVoteImplTest {
         + "id rsa1024 none");
     VoteBuilder.createWithStatusEntries(statusEntries);
   }
-}
 
+  @Test
+  public void testStatsLine()
+      throws DescriptorParseException {
+    List<String> statusEntries = new ArrayList<>();
+
+    statusEntries.add("r StarAppsMobley ACg7VWTjBy3N2rMdbvYi3Um/Uk8 "
+        + "aTvQmafGFlF6hfy9RfTfUsbhVgo 2023-03-07 04:06:02 195.15.242.99 9001 "
+        + "0\n"
+        + "a [2001:1600:10:100::201]:9001\n"
+        + "s Fast Running Stable V2Dir Valid\n"
+        + "v Tor 0.4.7.7\n"
+        + "pr Cons=1-2 Desc=1-2 DirCache=2 FlowCtrl=1-2 HSDir=2 HSIntro=4-5 "
+        + "HSRend=1-2 Link=1-5 LinkAuth=1,3 Microdesc=1-2 Padding=2 Relay=1-4\n"
+        + "w Bandwidth=10000 Measured=170000\n"
+        + "p reject 1-65535\n"
+        + "id ed25519 +SHwimxgO9wC2G5WQND6ZpaOGTe5dn8+JK2560mIfC4\n"
+        + "stats wfu=0.978224 tk=2298790 mtbf=968141\n"
+        + "m 28,29 sha256=nf/kZ8XQfBcrpn21wZ31ML29SmjqMWS3lckD0GkuIDI\n"
+        + "m 30,31,32 sha256=4vjkL72dR5lxLsoaUB3iWzCSuAaC4W+7UAFaQSEstUY");
+    RelayNetworkStatusVote vote =
+        VoteBuilder.createWithStatusEntries(statusEntries);
+    String fingerprint = "00283B5564E3072DCDDAB31D6EF622DD49BF524F";
+    assertEquals(String.valueOf(0.978224),
+        vote.getStatusEntry(fingerprint).getStats().get("wfu").toString());
+  }
+}
